# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ProductLicenseConsumerSummary(object):
    """
    Details of a resource that is consuming a particular product license.
    """

    #: A constant which can be used with the resource_unit_type property of a ProductLicenseConsumerSummary.
    #: This constant has a value of "OCPU"
    RESOURCE_UNIT_TYPE_OCPU = "OCPU"

    #: A constant which can be used with the license_unit_type property of a ProductLicenseConsumerSummary.
    #: This constant has a value of "OCPU"
    LICENSE_UNIT_TYPE_OCPU = "OCPU"

    #: A constant which can be used with the license_unit_type property of a ProductLicenseConsumerSummary.
    #: This constant has a value of "NAMED_USER_PLUS"
    LICENSE_UNIT_TYPE_NAMED_USER_PLUS = "NAMED_USER_PLUS"

    #: A constant which can be used with the license_unit_type property of a ProductLicenseConsumerSummary.
    #: This constant has a value of "PROCESSORS"
    LICENSE_UNIT_TYPE_PROCESSORS = "PROCESSORS"

    def __init__(self, **kwargs):
        """
        Initializes a new ProductLicenseConsumerSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param resource_id:
            The value to assign to the resource_id property of this ProductLicenseConsumerSummary.
        :type resource_id: str

        :param resource_name:
            The value to assign to the resource_name property of this ProductLicenseConsumerSummary.
        :type resource_name: str

        :param product_name:
            The value to assign to the product_name property of this ProductLicenseConsumerSummary.
        :type product_name: str

        :param resource_compartment_id:
            The value to assign to the resource_compartment_id property of this ProductLicenseConsumerSummary.
        :type resource_compartment_id: str

        :param resource_compartment_name:
            The value to assign to the resource_compartment_name property of this ProductLicenseConsumerSummary.
        :type resource_compartment_name: str

        :param resource_unit_type:
            The value to assign to the resource_unit_type property of this ProductLicenseConsumerSummary.
            Allowed values for this property are: "OCPU", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type resource_unit_type: str

        :param resource_unit_count:
            The value to assign to the resource_unit_count property of this ProductLicenseConsumerSummary.
        :type resource_unit_count: float

        :param license_unit_type:
            The value to assign to the license_unit_type property of this ProductLicenseConsumerSummary.
            Allowed values for this property are: "OCPU", "NAMED_USER_PLUS", "PROCESSORS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type license_unit_type: str

        :param license_units_consumed:
            The value to assign to the license_units_consumed property of this ProductLicenseConsumerSummary.
        :type license_units_consumed: float

        :param is_base_license_available:
            The value to assign to the is_base_license_available property of this ProductLicenseConsumerSummary.
        :type is_base_license_available: bool

        :param are_all_options_available:
            The value to assign to the are_all_options_available property of this ProductLicenseConsumerSummary.
        :type are_all_options_available: bool

        :param missing_products:
            The value to assign to the missing_products property of this ProductLicenseConsumerSummary.
        :type missing_products: list[oci.license_manager.models.Product]

        """
        self.swagger_types = {
            'resource_id': 'str',
            'resource_name': 'str',
            'product_name': 'str',
            'resource_compartment_id': 'str',
            'resource_compartment_name': 'str',
            'resource_unit_type': 'str',
            'resource_unit_count': 'float',
            'license_unit_type': 'str',
            'license_units_consumed': 'float',
            'is_base_license_available': 'bool',
            'are_all_options_available': 'bool',
            'missing_products': 'list[Product]'
        }

        self.attribute_map = {
            'resource_id': 'resourceId',
            'resource_name': 'resourceName',
            'product_name': 'productName',
            'resource_compartment_id': 'resourceCompartmentId',
            'resource_compartment_name': 'resourceCompartmentName',
            'resource_unit_type': 'resourceUnitType',
            'resource_unit_count': 'resourceUnitCount',
            'license_unit_type': 'licenseUnitType',
            'license_units_consumed': 'licenseUnitsConsumed',
            'is_base_license_available': 'isBaseLicenseAvailable',
            'are_all_options_available': 'areAllOptionsAvailable',
            'missing_products': 'missingProducts'
        }

        self._resource_id = None
        self._resource_name = None
        self._product_name = None
        self._resource_compartment_id = None
        self._resource_compartment_name = None
        self._resource_unit_type = None
        self._resource_unit_count = None
        self._license_unit_type = None
        self._license_units_consumed = None
        self._is_base_license_available = None
        self._are_all_options_available = None
        self._missing_products = None

    @property
    def resource_id(self):
        """
        **[Required]** Gets the resource_id of this ProductLicenseConsumerSummary.
        The `OCID`__ of the resource.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The resource_id of this ProductLicenseConsumerSummary.
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """
        Sets the resource_id of this ProductLicenseConsumerSummary.
        The `OCID`__ of the resource.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param resource_id: The resource_id of this ProductLicenseConsumerSummary.
        :type: str
        """
        self._resource_id = resource_id

    @property
    def resource_name(self):
        """
        **[Required]** Gets the resource_name of this ProductLicenseConsumerSummary.
        The display name of the resource.


        :return: The resource_name of this ProductLicenseConsumerSummary.
        :rtype: str
        """
        return self._resource_name

    @resource_name.setter
    def resource_name(self, resource_name):
        """
        Sets the resource_name of this ProductLicenseConsumerSummary.
        The display name of the resource.


        :param resource_name: The resource_name of this ProductLicenseConsumerSummary.
        :type: str
        """
        self._resource_name = resource_name

    @property
    def product_name(self):
        """
        **[Required]** Gets the product_name of this ProductLicenseConsumerSummary.
        The resource product name.


        :return: The product_name of this ProductLicenseConsumerSummary.
        :rtype: str
        """
        return self._product_name

    @product_name.setter
    def product_name(self, product_name):
        """
        Sets the product_name of this ProductLicenseConsumerSummary.
        The resource product name.


        :param product_name: The product_name of this ProductLicenseConsumerSummary.
        :type: str
        """
        self._product_name = product_name

    @property
    def resource_compartment_id(self):
        """
        **[Required]** Gets the resource_compartment_id of this ProductLicenseConsumerSummary.
        The `OCID`__ of the compartment that contains the resource.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The resource_compartment_id of this ProductLicenseConsumerSummary.
        :rtype: str
        """
        return self._resource_compartment_id

    @resource_compartment_id.setter
    def resource_compartment_id(self, resource_compartment_id):
        """
        Sets the resource_compartment_id of this ProductLicenseConsumerSummary.
        The `OCID`__ of the compartment that contains the resource.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param resource_compartment_id: The resource_compartment_id of this ProductLicenseConsumerSummary.
        :type: str
        """
        self._resource_compartment_id = resource_compartment_id

    @property
    def resource_compartment_name(self):
        """
        **[Required]** Gets the resource_compartment_name of this ProductLicenseConsumerSummary.
        The display name of the compartment that contains the resource.


        :return: The resource_compartment_name of this ProductLicenseConsumerSummary.
        :rtype: str
        """
        return self._resource_compartment_name

    @resource_compartment_name.setter
    def resource_compartment_name(self, resource_compartment_name):
        """
        Sets the resource_compartment_name of this ProductLicenseConsumerSummary.
        The display name of the compartment that contains the resource.


        :param resource_compartment_name: The resource_compartment_name of this ProductLicenseConsumerSummary.
        :type: str
        """
        self._resource_compartment_name = resource_compartment_name

    @property
    def resource_unit_type(self):
        """
        **[Required]** Gets the resource_unit_type of this ProductLicenseConsumerSummary.
        The unit type for the resource.

        Allowed values for this property are: "OCPU", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The resource_unit_type of this ProductLicenseConsumerSummary.
        :rtype: str
        """
        return self._resource_unit_type

    @resource_unit_type.setter
    def resource_unit_type(self, resource_unit_type):
        """
        Sets the resource_unit_type of this ProductLicenseConsumerSummary.
        The unit type for the resource.


        :param resource_unit_type: The resource_unit_type of this ProductLicenseConsumerSummary.
        :type: str
        """
        allowed_values = ["OCPU"]
        if not value_allowed_none_or_none_sentinel(resource_unit_type, allowed_values):
            resource_unit_type = 'UNKNOWN_ENUM_VALUE'
        self._resource_unit_type = resource_unit_type

    @property
    def resource_unit_count(self):
        """
        **[Required]** Gets the resource_unit_count of this ProductLicenseConsumerSummary.
        Number of units of the resource


        :return: The resource_unit_count of this ProductLicenseConsumerSummary.
        :rtype: float
        """
        return self._resource_unit_count

    @resource_unit_count.setter
    def resource_unit_count(self, resource_unit_count):
        """
        Sets the resource_unit_count of this ProductLicenseConsumerSummary.
        Number of units of the resource


        :param resource_unit_count: The resource_unit_count of this ProductLicenseConsumerSummary.
        :type: float
        """
        self._resource_unit_count = resource_unit_count

    @property
    def license_unit_type(self):
        """
        **[Required]** Gets the license_unit_type of this ProductLicenseConsumerSummary.
        The product license unit.

        Allowed values for this property are: "OCPU", "NAMED_USER_PLUS", "PROCESSORS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The license_unit_type of this ProductLicenseConsumerSummary.
        :rtype: str
        """
        return self._license_unit_type

    @license_unit_type.setter
    def license_unit_type(self, license_unit_type):
        """
        Sets the license_unit_type of this ProductLicenseConsumerSummary.
        The product license unit.


        :param license_unit_type: The license_unit_type of this ProductLicenseConsumerSummary.
        :type: str
        """
        allowed_values = ["OCPU", "NAMED_USER_PLUS", "PROCESSORS"]
        if not value_allowed_none_or_none_sentinel(license_unit_type, allowed_values):
            license_unit_type = 'UNKNOWN_ENUM_VALUE'
        self._license_unit_type = license_unit_type

    @property
    def license_units_consumed(self):
        """
        **[Required]** Gets the license_units_consumed of this ProductLicenseConsumerSummary.
        Number of license units consumed by the resource.


        :return: The license_units_consumed of this ProductLicenseConsumerSummary.
        :rtype: float
        """
        return self._license_units_consumed

    @license_units_consumed.setter
    def license_units_consumed(self, license_units_consumed):
        """
        Sets the license_units_consumed of this ProductLicenseConsumerSummary.
        Number of license units consumed by the resource.


        :param license_units_consumed: The license_units_consumed of this ProductLicenseConsumerSummary.
        :type: float
        """
        self._license_units_consumed = license_units_consumed

    @property
    def is_base_license_available(self):
        """
        **[Required]** Gets the is_base_license_available of this ProductLicenseConsumerSummary.
        Specifies if the base license is available.


        :return: The is_base_license_available of this ProductLicenseConsumerSummary.
        :rtype: bool
        """
        return self._is_base_license_available

    @is_base_license_available.setter
    def is_base_license_available(self, is_base_license_available):
        """
        Sets the is_base_license_available of this ProductLicenseConsumerSummary.
        Specifies if the base license is available.


        :param is_base_license_available: The is_base_license_available of this ProductLicenseConsumerSummary.
        :type: bool
        """
        self._is_base_license_available = is_base_license_available

    @property
    def are_all_options_available(self):
        """
        **[Required]** Gets the are_all_options_available of this ProductLicenseConsumerSummary.
        Specifies if all options are available.


        :return: The are_all_options_available of this ProductLicenseConsumerSummary.
        :rtype: bool
        """
        return self._are_all_options_available

    @are_all_options_available.setter
    def are_all_options_available(self, are_all_options_available):
        """
        Sets the are_all_options_available of this ProductLicenseConsumerSummary.
        Specifies if all options are available.


        :param are_all_options_available: The are_all_options_available of this ProductLicenseConsumerSummary.
        :type: bool
        """
        self._are_all_options_available = are_all_options_available

    @property
    def missing_products(self):
        """
        **[Required]** Gets the missing_products of this ProductLicenseConsumerSummary.
        Collection of missing product licenses.


        :return: The missing_products of this ProductLicenseConsumerSummary.
        :rtype: list[oci.license_manager.models.Product]
        """
        return self._missing_products

    @missing_products.setter
    def missing_products(self, missing_products):
        """
        Sets the missing_products of this ProductLicenseConsumerSummary.
        Collection of missing product licenses.


        :param missing_products: The missing_products of this ProductLicenseConsumerSummary.
        :type: list[oci.license_manager.models.Product]
        """
        self._missing_products = missing_products

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from oci._vendor import requests  # noqa: F401
from oci._vendor import six

from oci import retry, circuit_breaker  # noqa: F401
from oci.base_client import BaseClient
from oci.config import get_config_value_or_default, validate_config
from oci.signer import Signer
from oci.util import Sentinel, get_signer_from_authentication_type, AUTHENTICATION_TYPE_FIELD_NAME
from .models import waa_type_mapping
missing = Sentinel("Missing")


class WaaClient(object):
    """
    API for the Web Application Acceleration service.
    Use this API to manage regional Web App Acceleration policies such as Caching and Compression
    for accelerating HTTP services.
    """

    def __init__(self, config, **kwargs):
        """
        Creates a new service client

        :param dict config:
            Configuration keys and values as per `SDK and Tool Configuration <https://docs.cloud.oracle.com/Content/API/Concepts/sdkconfig.htm>`__.
            The :py:meth:`~oci.config.from_file` method can be used to load configuration from a file. Alternatively, a ``dict`` can be passed. You can validate_config
            the dict using :py:meth:`~oci.config.validate_config`

        :param str service_endpoint: (optional)
            The endpoint of the service to call using this client. For example ``https://iaas.us-ashburn-1.oraclecloud.com``. If this keyword argument is
            not provided then it will be derived using the region in the config parameter. You should only provide this keyword argument if you have an explicit
            need to specify a service endpoint.

        :param timeout: (optional)
            The connection and read timeouts for the client. The default values are connection timeout 10 seconds and read timeout 60 seconds. This keyword argument can be provided
            as a single float, in which case the value provided is used for both the read and connection timeouts, or as a tuple of two floats. If
            a tuple is provided then the first value is used as the connection timeout and the second value as the read timeout.
        :type timeout: float or tuple(float, float)

        :param signer: (optional)
            The signer to use when signing requests made by the service client. The default is to use a :py:class:`~oci.signer.Signer` based on the values
            provided in the config parameter.

            One use case for this parameter is for `Instance Principals authentication <https://docs.cloud.oracle.com/Content/Identity/Tasks/callingservicesfrominstances.htm>`__
            by passing an instance of :py:class:`~oci.auth.signers.InstancePrincipalsSecurityTokenSigner` as the value for this keyword argument
        :type signer: :py:class:`~oci.signer.AbstractBaseSigner`

        :param obj retry_strategy: (optional)
            A retry strategy to apply to all calls made by this service client (i.e. at the client level). There is no retry strategy applied by default.
            Retry strategies can also be applied at the operation level by passing a ``retry_strategy`` keyword argument as part of calling the operation.
            Any value provided at the operation level will override whatever is specified at the client level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

        :param obj circuit_breaker_strategy: (optional)
            A circuit breaker strategy to apply to all calls made by this service client (i.e. at the client level).
            This client uses :py:data:`~oci.circuit_breaker.DEFAULT_CIRCUIT_BREAKER_STRATEGY` as default if no circuit breaker strategy is provided.
            The specifics of circuit breaker strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/circuit_breakers.html>`__.

        :param function circuit_breaker_callback: (optional)
            Callback function to receive any exceptions triggerred by the circuit breaker.

        :param allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this client should allow control characters in the response object. By default, the client will not
            allow control characters to be in the response object.
        """
        validate_config(config, signer=kwargs.get('signer'))
        if 'signer' in kwargs:
            signer = kwargs['signer']

        elif AUTHENTICATION_TYPE_FIELD_NAME in config:
            signer = get_signer_from_authentication_type(config)

        else:
            signer = Signer(
                tenancy=config["tenancy"],
                user=config["user"],
                fingerprint=config["fingerprint"],
                private_key_file_location=config.get("key_file"),
                pass_phrase=get_config_value_or_default(config, "pass_phrase"),
                private_key_content=config.get("key_content")
            )

        base_client_init_kwargs = {
            'regional_client': True,
            'service_endpoint': kwargs.get('service_endpoint'),
            'base_path': '/20211230',
            'service_endpoint_template': 'https://waa.{region}.oci.{secondLevelDomain}',
            'skip_deserialization': kwargs.get('skip_deserialization', False),
            'circuit_breaker_strategy': kwargs.get('circuit_breaker_strategy', circuit_breaker.GLOBAL_CIRCUIT_BREAKER_STRATEGY)
        }
        if 'timeout' in kwargs:
            base_client_init_kwargs['timeout'] = kwargs.get('timeout')
        if base_client_init_kwargs.get('circuit_breaker_strategy') is None:
            base_client_init_kwargs['circuit_breaker_strategy'] = circuit_breaker.DEFAULT_CIRCUIT_BREAKER_STRATEGY
        if 'allow_control_chars' in kwargs:
            base_client_init_kwargs['allow_control_chars'] = kwargs.get('allow_control_chars')
        self.base_client = BaseClient("waa", config, signer, waa_type_mapping, **base_client_init_kwargs)
        self.retry_strategy = kwargs.get('retry_strategy')
        self.circuit_breaker_callback = kwargs.get('circuit_breaker_callback')

    def change_web_app_acceleration_compartment(self, web_app_acceleration_id, change_web_app_acceleration_compartment_details, **kwargs):
        """
        Moves a Web App Acceleration resource from one compartment to another.
        When provided, If-Match is checked against ETag values of the resource.


        :param str web_app_acceleration_id: (required)
            The `OCID`__ of the WebAppAcceleration.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.waa.models.ChangeWebAppAccelerationCompartmentDetails change_web_app_acceleration_compartment_details: (required)
            The information to be updated.

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call for a resource,
            set the `if-match` parameter to the value of the etag from a previous GET or POST response for that resource.
            The resource will be updated or deleted only if the etag you provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            The client request ID for tracing.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation will not retry by default, users can also use the convenient :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` provided by the SDK to enable retries for it.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.75.0/waa/change_web_app_acceleration_compartment.py.html>`__ to see an example of how to use change_web_app_acceleration_compartment API.
        """
        resource_path = "/webAppAccelerations/{webAppAccelerationId}/actions/changeCompartment"
        method = "POST"
        operation_name = "change_web_app_acceleration_compartment"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/waa/20211230/WebAppAcceleration/ChangeWebAppAccelerationCompartment"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "change_web_app_acceleration_compartment got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "webAppAccelerationId": web_app_acceleration_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=change_web_app_acceleration_compartment_details,
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=change_web_app_acceleration_compartment_details,
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)

    def change_web_app_acceleration_policy_compartment(self, web_app_acceleration_policy_id, change_web_app_acceleration_policy_compartment_details, **kwargs):
        """
        Moves a WebAppAccelerationfPolicy resource from one compartment to another.
        When provided, If-Match is checked against ETag values of the resource.


        :param str web_app_acceleration_policy_id: (required)
            The `OCID`__ of the WebAppAccelerationPolicy.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.waa.models.ChangeWebAppAccelerationPolicyCompartmentDetails change_web_app_acceleration_policy_compartment_details: (required)
            The information to be updated.

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call for a resource,
            set the `if-match` parameter to the value of the etag from a previous GET or POST response for that resource.
            The resource will be updated or deleted only if the etag you provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            The client request ID for tracing.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation will not retry by default, users can also use the convenient :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` provided by the SDK to enable retries for it.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.75.0/waa/change_web_app_acceleration_policy_compartment.py.html>`__ to see an example of how to use change_web_app_acceleration_policy_compartment API.
        """
        resource_path = "/webAppAccelerationPolicies/{webAppAccelerationPolicyId}/actions/changeCompartment"
        method = "POST"
        operation_name = "change_web_app_acceleration_policy_compartment"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/waa/20211230/WebAppAccelerationPolicy/ChangeWebAppAccelerationPolicyCompartment"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "change_web_app_acceleration_policy_compartment got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "webAppAccelerationPolicyId": web_app_acceleration_policy_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=change_web_app_acceleration_policy_compartment_details,
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=change_web_app_acceleration_policy_compartment_details,
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)

    def create_web_app_acceleration(self, create_web_app_acceleration_details, **kwargs):
        """
        Creates a new WebAppAcceleration.


        :param oci.waa.models.CreateWebAppAccelerationDetails create_web_app_acceleration_details: (required)
            Details for the new WebAppAcceleration.

        :param str opc_retry_token: (optional)
            A token that uniquely identifies a request so it can be retried in case of a timeout or
            server error without risk of executing that same action again. Retry tokens expire after 24
            hours, but can be invalidated before then due to conflicting operations. For example, if a resource
            has been deleted and purged from the system, then a retry of the original creation request might be rejected.

        :param str opc_request_id: (optional)
            The client request ID for tracing.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation will not retry by default, users can also use the convenient :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` provided by the SDK to enable retries for it.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.waa.models.WebAppAcceleration`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.75.0/waa/create_web_app_acceleration.py.html>`__ to see an example of how to use create_web_app_acceleration API.
        """
        resource_path = "/webAppAccelerations"
        method = "POST"
        operation_name = "create_web_app_acceleration"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/waa/20211230/WebAppAcceleration/CreateWebAppAcceleration"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "opc_retry_token",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "create_web_app_acceleration got unknown kwargs: {!r}".format(extra_kwargs))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-retry-token": kwargs.get("opc_retry_token", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_retry_token_if_needed(header_params)
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                header_params=header_params,
                body=create_web_app_acceleration_details,
                response_type="WebAppAcceleration",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                header_params=header_params,
                body=create_web_app_acceleration_details,
                response_type="WebAppAcceleration",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)

    def create_web_app_acceleration_policy(self, create_web_app_acceleration_policy_details, **kwargs):
        """
        Creates a new WebAppAccelerationPolicy.


        :param oci.waa.models.CreateWebAppAccelerationPolicyDetails create_web_app_acceleration_policy_details: (required)
            Details for the new WebAppAccelerationPolicy.

        :param str opc_retry_token: (optional)
            A token that uniquely identifies a request so it can be retried in case of a timeout or
            server error without risk of executing that same action again. Retry tokens expire after 24
            hours, but can be invalidated before then due to conflicting operations. For example, if a resource
            has been deleted and purged from the system, then a retry of the original creation request might be rejected.

        :param str opc_request_id: (optional)
            The client request ID for tracing.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation will not retry by default, users can also use the convenient :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` provided by the SDK to enable retries for it.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.waa.models.WebAppAccelerationPolicy`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.75.0/waa/create_web_app_acceleration_policy.py.html>`__ to see an example of how to use create_web_app_acceleration_policy API.
        """
        resource_path = "/webAppAccelerationPolicies"
        method = "POST"
        operation_name = "create_web_app_acceleration_policy"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/waa/20211230/WebAppAccelerationPolicy/CreateWebAppAccelerationPolicy"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "opc_retry_token",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "create_web_app_acceleration_policy got unknown kwargs: {!r}".format(extra_kwargs))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-retry-token": kwargs.get("opc_retry_token", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_retry_token_if_needed(header_params)
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                header_params=header_params,
                body=create_web_app_acceleration_policy_details,
                response_type="WebAppAccelerationPolicy",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                header_params=header_params,
                body=create_web_app_acceleration_policy_details,
                response_type="WebAppAccelerationPolicy",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)

    def delete_web_app_acceleration(self, web_app_acceleration_id, **kwargs):
        """
        Deletes a WebAppAcceleration resource identified by the OCID.


        :param str web_app_acceleration_id: (required)
            The `OCID`__ of the WebAppAcceleration.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call for a resource,
            set the `if-match` parameter to the value of the etag from a previous GET or POST response for that resource.
            The resource will be updated or deleted only if the etag you provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            The client request ID for tracing.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation will not retry by default, users can also use the convenient :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` provided by the SDK to enable retries for it.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.75.0/waa/delete_web_app_acceleration.py.html>`__ to see an example of how to use delete_web_app_acceleration API.
        """
        resource_path = "/webAppAccelerations/{webAppAccelerationId}"
        method = "DELETE"
        operation_name = "delete_web_app_acceleration"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/waa/20211230/WebAppAcceleration/DeleteWebAppAcceleration"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "delete_web_app_acceleration got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "webAppAccelerationId": web_app_acceleration_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)

    def delete_web_app_acceleration_policy(self, web_app_acceleration_policy_id, **kwargs):
        """
        Deletes a WebAppAccelerationPolicy resource identified by the OCID.


        :param str web_app_acceleration_policy_id: (required)
            The `OCID`__ of the WebAppAccelerationPolicy.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call for a resource,
            set the `if-match` parameter to the value of the etag from a previous GET or POST response for that resource.
            The resource will be updated or deleted only if the etag you provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            The client request ID for tracing.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation will not retry by default, users can also use the convenient :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` provided by the SDK to enable retries for it.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.75.0/waa/delete_web_app_acceleration_policy.py.html>`__ to see an example of how to use delete_web_app_acceleration_policy API.
        """
        resource_path = "/webAppAccelerationPolicies/{webAppAccelerationPolicyId}"
        method = "DELETE"
        operation_name = "delete_web_app_acceleration_policy"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/waa/20211230/WebAppAccelerationPolicy/DeleteWebAppAccelerationPolicy"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "delete_web_app_acceleration_policy got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "webAppAccelerationPolicyId": web_app_acceleration_policy_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)

    def get_web_app_acceleration(self, web_app_acceleration_id, **kwargs):
        """
        Gets a WebAppAcceleration by OCID.


        :param str web_app_acceleration_id: (required)
            The `OCID`__ of the WebAppAcceleration.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param str opc_request_id: (optional)
            The client request ID for tracing.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation will not retry by default, users can also use the convenient :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` provided by the SDK to enable retries for it.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.waa.models.WebAppAcceleration`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.75.0/waa/get_web_app_acceleration.py.html>`__ to see an example of how to use get_web_app_acceleration API.
        """
        resource_path = "/webAppAccelerations/{webAppAccelerationId}"
        method = "GET"
        operation_name = "get_web_app_acceleration"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/waa/20211230/WebAppAcceleration/GetWebAppAcceleration"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "get_web_app_acceleration got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "webAppAccelerationId": web_app_acceleration_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                response_type="WebAppAcceleration",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                response_type="WebAppAcceleration",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)

    def get_web_app_acceleration_policy(self, web_app_acceleration_policy_id, **kwargs):
        """
        Gets a WebAppAccelerationPolicy with the given OCID.


        :param str web_app_acceleration_policy_id: (required)
            The `OCID`__ of the WebAppAccelerationPolicy.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param str opc_request_id: (optional)
            The client request ID for tracing.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation will not retry by default, users can also use the convenient :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` provided by the SDK to enable retries for it.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.waa.models.WebAppAccelerationPolicy`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.75.0/waa/get_web_app_acceleration_policy.py.html>`__ to see an example of how to use get_web_app_acceleration_policy API.
        """
        resource_path = "/webAppAccelerationPolicies/{webAppAccelerationPolicyId}"
        method = "GET"
        operation_name = "get_web_app_acceleration_policy"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/waa/20211230/WebAppAccelerationPolicy/GetWebAppAccelerationPolicy"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "get_web_app_acceleration_policy got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "webAppAccelerationPolicyId": web_app_acceleration_policy_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                response_type="WebAppAccelerationPolicy",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                response_type="WebAppAccelerationPolicy",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)

    def list_web_app_acceleration_policies(self, compartment_id, **kwargs):
        """
        Gets a list of all WebAppAccelerationPolicies in a compartment.


        :param str compartment_id: (required)
            The `OCID`__ of the compartment in which to list resources.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param list[WebAppAccelerationPolicyLifecycleState] lifecycle_state: (optional)
            A filter to return only resources that match the given lifecycleState.

        :param str display_name: (optional)
            A filter to return only resources that match the entire display name given.

        :param str id: (optional)
            A filter to return only the WebAppAccelerationPolicy with the given `OCID`__.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param int limit: (optional)
            The maximum number of items to return.

        :param str page: (optional)
            A token representing the position at which to start retrieving results.
            This must come from the `opc-next-page` header field of a previous response.

        :param str sort_order: (optional)
            The sort order to use, either 'ASC' or 'DESC'.

            Allowed values are: "ASC", "DESC"

        :param str sort_by: (optional)
            The field to sort by. Only one sort order may be provided.
            Default order for timeCreated is descending.
            Default order for displayName is ascending.
            If no value is specified timeCreated is default.

            Allowed values are: "timeCreated", "displayName"

        :param str opc_request_id: (optional)
            The client request ID for tracing.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation will not retry by default, users can also use the convenient :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` provided by the SDK to enable retries for it.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.waa.models.WebAppAccelerationPolicyCollection`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.75.0/waa/list_web_app_acceleration_policies.py.html>`__ to see an example of how to use list_web_app_acceleration_policies API.
        """
        resource_path = "/webAppAccelerationPolicies"
        method = "GET"
        operation_name = "list_web_app_acceleration_policies"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/waa/20211230/WebAppAccelerationPolicy/ListWebAppAccelerationPolicies"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "lifecycle_state",
            "display_name",
            "id",
            "limit",
            "page",
            "sort_order",
            "sort_by",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "list_web_app_acceleration_policies got unknown kwargs: {!r}".format(extra_kwargs))

        if 'sort_order' in kwargs:
            sort_order_allowed_values = ["ASC", "DESC"]
            if kwargs['sort_order'] not in sort_order_allowed_values:
                raise ValueError(
                    "Invalid value for `sort_order`, must be one of {0}".format(sort_order_allowed_values)
                )

        if 'sort_by' in kwargs:
            sort_by_allowed_values = ["timeCreated", "displayName"]
            if kwargs['sort_by'] not in sort_by_allowed_values:
                raise ValueError(
                    "Invalid value for `sort_by`, must be one of {0}".format(sort_by_allowed_values)
                )

        query_params = {
            "compartmentId": compartment_id,
            "lifecycleState": self.base_client.generate_collection_format_param(kwargs.get("lifecycle_state", missing), 'multi'),
            "displayName": kwargs.get("display_name", missing),
            "id": kwargs.get("id", missing),
            "limit": kwargs.get("limit", missing),
            "page": kwargs.get("page", missing),
            "sortOrder": kwargs.get("sort_order", missing),
            "sortBy": kwargs.get("sort_by", missing)
        }
        query_params = {k: v for (k, v) in six.iteritems(query_params) if v is not missing and v is not None}

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="WebAppAccelerationPolicyCollection",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="WebAppAccelerationPolicyCollection",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)

    def list_web_app_accelerations(self, compartment_id, **kwargs):
        """
        Gets a list of all WebAppAccelerations in a compartment.


        :param str compartment_id: (required)
            The `OCID`__ of the compartment in which to list resources.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param str id: (optional)
            A filter to return only the WebAppAcceleration with the given `OCID`__.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param str web_app_acceleration_policy_id: (optional)
            A filter to return only the WebAppAcceleration with the given
            `OCID`__ of related WebAppAccelerationPolicy.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param list[WebAppAccelerationLifecycleState] lifecycle_state: (optional)
            A filter to return only resources that match the given lifecycleState.

        :param str display_name: (optional)
            A filter to return only resources that match the entire display name given.

        :param int limit: (optional)
            The maximum number of items to return.

        :param str page: (optional)
            A token representing the position at which to start retrieving results.
            This must come from the `opc-next-page` header field of a previous response.

        :param str sort_order: (optional)
            The sort order to use, either 'ASC' or 'DESC'.

            Allowed values are: "ASC", "DESC"

        :param str sort_by: (optional)
            The field to sort by. Only one sort order may be provided.
            Default order for timeCreated is descending.
            Default order for displayName is ascending.
            If no value is specified timeCreated is default.

            Allowed values are: "timeCreated", "displayName"

        :param str opc_request_id: (optional)
            The client request ID for tracing.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation will not retry by default, users can also use the convenient :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` provided by the SDK to enable retries for it.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.waa.models.WebAppAccelerationCollection`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.75.0/waa/list_web_app_accelerations.py.html>`__ to see an example of how to use list_web_app_accelerations API.
        """
        resource_path = "/webAppAccelerations"
        method = "GET"
        operation_name = "list_web_app_accelerations"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/waa/20211230/WebAppAcceleration/ListWebAppAccelerations"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "id",
            "web_app_acceleration_policy_id",
            "lifecycle_state",
            "display_name",
            "limit",
            "page",
            "sort_order",
            "sort_by",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "list_web_app_accelerations got unknown kwargs: {!r}".format(extra_kwargs))

        if 'sort_order' in kwargs:
            sort_order_allowed_values = ["ASC", "DESC"]
            if kwargs['sort_order'] not in sort_order_allowed_values:
                raise ValueError(
                    "Invalid value for `sort_order`, must be one of {0}".format(sort_order_allowed_values)
                )

        if 'sort_by' in kwargs:
            sort_by_allowed_values = ["timeCreated", "displayName"]
            if kwargs['sort_by'] not in sort_by_allowed_values:
                raise ValueError(
                    "Invalid value for `sort_by`, must be one of {0}".format(sort_by_allowed_values)
                )

        query_params = {
            "compartmentId": compartment_id,
            "id": kwargs.get("id", missing),
            "webAppAccelerationPolicyId": kwargs.get("web_app_acceleration_policy_id", missing),
            "lifecycleState": self.base_client.generate_collection_format_param(kwargs.get("lifecycle_state", missing), 'multi'),
            "displayName": kwargs.get("display_name", missing),
            "limit": kwargs.get("limit", missing),
            "page": kwargs.get("page", missing),
            "sortOrder": kwargs.get("sort_order", missing),
            "sortBy": kwargs.get("sort_by", missing)
        }
        query_params = {k: v for (k, v) in six.iteritems(query_params) if v is not missing and v is not None}

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="WebAppAccelerationCollection",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="WebAppAccelerationCollection",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)

    def purge_web_app_acceleration_cache(self, web_app_acceleration_id, purge_web_app_acceleration_cache_details, **kwargs):
        """
        Clears resources from the cache of the WebAppAcceleration. Each new request for a purged resource will be
        forwarded to the origin server to fetch a new version of the resource.


        :param str web_app_acceleration_id: (required)
            The `OCID`__ of the WebAppAcceleration.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.waa.models.PurgeWebAppAccelerationCacheDetails purge_web_app_acceleration_cache_details: (required)
            Options for the cache purge.

        :param str opc_request_id: (optional)
            The client request ID for tracing.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation will not retry by default, users can also use the convenient :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` provided by the SDK to enable retries for it.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.75.0/waa/purge_web_app_acceleration_cache.py.html>`__ to see an example of how to use purge_web_app_acceleration_cache API.
        """
        resource_path = "/webAppAccelerations/{webAppAccelerationId}/actions/purgeCache"
        method = "POST"
        operation_name = "purge_web_app_acceleration_cache"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/waa/20211230/WebAppAcceleration/PurgeWebAppAccelerationCache"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "purge_web_app_acceleration_cache got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "webAppAccelerationId": web_app_acceleration_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=purge_web_app_acceleration_cache_details,
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=purge_web_app_acceleration_cache_details,
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)

    def update_web_app_acceleration(self, web_app_acceleration_id, update_web_app_acceleration_details, **kwargs):
        """
        Updates the WebAppAcceleration identified by the OCID.


        :param str web_app_acceleration_id: (required)
            The `OCID`__ of the WebAppAcceleration.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.waa.models.UpdateWebAppAccelerationDetails update_web_app_acceleration_details: (required)
            The information to be updated.

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call for a resource,
            set the `if-match` parameter to the value of the etag from a previous GET or POST response for that resource.
            The resource will be updated or deleted only if the etag you provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            The client request ID for tracing.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation will not retry by default, users can also use the convenient :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` provided by the SDK to enable retries for it.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.75.0/waa/update_web_app_acceleration.py.html>`__ to see an example of how to use update_web_app_acceleration API.
        """
        resource_path = "/webAppAccelerations/{webAppAccelerationId}"
        method = "PUT"
        operation_name = "update_web_app_acceleration"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/waa/20211230/WebAppAcceleration/UpdateWebAppAcceleration"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "update_web_app_acceleration got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "webAppAccelerationId": web_app_acceleration_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=update_web_app_acceleration_details,
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=update_web_app_acceleration_details,
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)

    def update_web_app_acceleration_policy(self, web_app_acceleration_policy_id, update_web_app_acceleration_policy_details, **kwargs):
        """
        Update the WebAppAccelerationPolicy identified by the OCID.


        :param str web_app_acceleration_policy_id: (required)
            The `OCID`__ of the WebAppAccelerationPolicy.

            __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm

        :param oci.waa.models.UpdateWebAppAccelerationPolicyDetails update_web_app_acceleration_policy_details: (required)
            The information to be updated.

        :param str if_match: (optional)
            For optimistic concurrency control. In the PUT or DELETE call for a resource,
            set the `if-match` parameter to the value of the etag from a previous GET or POST response for that resource.
            The resource will be updated or deleted only if the etag you provide matches the resource's current etag value.

        :param str opc_request_id: (optional)
            The client request ID for tracing.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation will not retry by default, users can also use the convenient :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` provided by the SDK to enable retries for it.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.75.0/waa/update_web_app_acceleration_policy.py.html>`__ to see an example of how to use update_web_app_acceleration_policy API.
        """
        resource_path = "/webAppAccelerationPolicies/{webAppAccelerationPolicyId}"
        method = "PUT"
        operation_name = "update_web_app_acceleration_policy"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/waa/20211230/WebAppAccelerationPolicy/UpdateWebAppAccelerationPolicy"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "update_web_app_acceleration_policy got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "webAppAccelerationPolicyId": web_app_acceleration_policy_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=update_web_app_acceleration_policy_details,
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=update_web_app_acceleration_policy_details,
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .access_denied_traffic_node import AccessDeniedTrafficNode
from .add_drg_route_distribution_statement_details import AddDrgRouteDistributionStatementDetails
from .add_drg_route_distribution_statements_details import AddDrgRouteDistributionStatementsDetails
from .add_drg_route_rule_details import AddDrgRouteRuleDetails
from .add_drg_route_rules_details import AddDrgRouteRulesDetails
from .add_network_security_group_security_rules_details import AddNetworkSecurityGroupSecurityRulesDetails
from .add_security_rule_details import AddSecurityRuleDetails
from .added_network_security_group_security_rules import AddedNetworkSecurityGroupSecurityRules
from .adhoc_get_path_analysis_details import AdhocGetPathAnalysisDetails
from .allowed_security_action import AllowedSecurityAction
from .allowed_security_action_details import AllowedSecurityActionDetails
from .allowed_security_configuration import AllowedSecurityConfiguration
from .bulk_add_virtual_circuit_public_prefixes_details import BulkAddVirtualCircuitPublicPrefixesDetails
from .bulk_delete_virtual_circuit_public_prefixes_details import BulkDeleteVirtualCircuitPublicPrefixesDetails
from .change_path_analyzer_test_compartment_details import ChangePathAnalyzerTestCompartmentDetails
from .compartment_internal import CompartmentInternal
from .compute_instance_endpoint import ComputeInstanceEndpoint
from .connect_local_peering_gateways_details import ConnectLocalPeeringGatewaysDetails
from .connect_remote_peering_connections_details import ConnectRemotePeeringConnectionsDetails
from .cpe import Cpe
from .create_cpe_details import CreateCpeDetails
from .create_cross_connect_details import CreateCrossConnectDetails
from .create_cross_connect_group_details import CreateCrossConnectGroupDetails
from .create_dhcp_details import CreateDhcpDetails
from .create_drg_attachment_details import CreateDrgAttachmentDetails
from .create_drg_details import CreateDrgDetails
from .create_drg_route_distribution_details import CreateDrgRouteDistributionDetails
from .create_drg_route_table_details import CreateDrgRouteTableDetails
from .create_ip_sec_connection_details import CreateIPSecConnectionDetails
from .create_internet_gateway_details import CreateInternetGatewayDetails
from .create_ipv6_details import CreateIpv6Details
from .create_local_peering_gateway_details import CreateLocalPeeringGatewayDetails
from .create_network_security_group_details import CreateNetworkSecurityGroupDetails
from .create_path_analyzer_test_details import CreatePathAnalyzerTestDetails
from .create_private_ip_details import CreatePrivateIpDetails
from .create_public_ip_details import CreatePublicIpDetails
from .create_remote_peering_connection_details import CreateRemotePeeringConnectionDetails
from .create_route_table_details import CreateRouteTableDetails
from .create_security_list_details import CreateSecurityListDetails
from .create_service_gateway_details import CreateServiceGatewayDetails
from .create_subnet_details import CreateSubnetDetails
from .create_vcn_details import CreateVcnDetails
from .create_virtual_circuit_details import CreateVirtualCircuitDetails
from .create_virtual_circuit_public_prefix_details import CreateVirtualCircuitPublicPrefixDetails
from .create_vnic_details import CreateVnicDetails
from .cross_connect import CrossConnect
from .cross_connect_group import CrossConnectGroup
from .cross_connect_location import CrossConnectLocation
from .cross_connect_mapping import CrossConnectMapping
from .cross_connect_port_speed_shape import CrossConnectPortSpeedShape
from .cross_connect_status import CrossConnectStatus
from .default_drg_route_tables import DefaultDrgRouteTables
from .delete_virtual_circuit_public_prefix_details import DeleteVirtualCircuitPublicPrefixDetails
from .denied_security_action import DeniedSecurityAction
from .denied_security_action_details import DeniedSecurityActionDetails
from .dhcp_dns_option import DhcpDnsOption
from .dhcp_option import DhcpOption
from .dhcp_options import DhcpOptions
from .dhcp_search_domain_option import DhcpSearchDomainOption
from .drg import Drg
from .drg_attachment import DrgAttachment
from .drg_attachment_id_drg_route_distribution_match_criteria import DrgAttachmentIdDrgRouteDistributionMatchCriteria
from .drg_attachment_info import DrgAttachmentInfo
from .drg_attachment_network_create_details import DrgAttachmentNetworkCreateDetails
from .drg_attachment_network_details import DrgAttachmentNetworkDetails
from .drg_attachment_network_update_details import DrgAttachmentNetworkUpdateDetails
from .drg_attachment_type_drg_route_distribution_match_criteria import DrgAttachmentTypeDrgRouteDistributionMatchCriteria
from .drg_route_distribution import DrgRouteDistribution
from .drg_route_distribution_match_criteria import DrgRouteDistributionMatchCriteria
from .drg_route_distribution_statement import DrgRouteDistributionStatement
from .drg_route_rule import DrgRouteRule
from .drg_route_table import DrgRouteTable
from .drg_routing_configuration import DrgRoutingConfiguration
from .egress_security_list_configuration import EgressSecurityListConfiguration
from .egress_security_rule import EgressSecurityRule
from .egress_traffic_spec import EgressTrafficSpec
from .endpoint import Endpoint
from .fast_connect_provider_service import FastConnectProviderService
from .forwarded_routing_action import ForwardedRoutingAction
from .forwarded_routing_action_details import ForwardedRoutingActionDetails
from .forwarded_routing_configuration import ForwardedRoutingConfiguration
from .get_path_analysis_details import GetPathAnalysisDetails
from .get_public_ip_by_ip_address_details import GetPublicIpByIpAddressDetails
from .get_public_ip_by_private_ip_id_details import GetPublicIpByPrivateIpIdDetails
from .ip_sec_connection import IPSecConnection
from .ip_sec_connection_device_config import IPSecConnectionDeviceConfig
from .ip_sec_connection_device_status import IPSecConnectionDeviceStatus
from .icmp_options import IcmpOptions
from .icmp_protocol_parameters import IcmpProtocolParameters
from .icmp_traffic_protocol_parameters import IcmpTrafficProtocolParameters
from .indeterminate_routing_action import IndeterminateRoutingAction
from .ingress_security_list_configuration import IngressSecurityListConfiguration
from .ingress_security_rule import IngressSecurityRule
from .internet_gateway import InternetGateway
from .ip_address_endpoint import IpAddressEndpoint
from .ipsec_tunnel_drg_attachment_network_details import IpsecTunnelDrgAttachmentNetworkDetails
from .ipv6 import Ipv6
from .letter_of_authority import LetterOfAuthority
from .load_balancer_endpoint import LoadBalancerEndpoint
from .load_balancer_listener_endpoint import LoadBalancerListenerEndpoint
from .local_peering_gateway import LocalPeeringGateway
from .network_load_balancer_endpoint import NetworkLoadBalancerEndpoint
from .network_load_balancer_listener_endpoint import NetworkLoadBalancerListenerEndpoint
from .network_security_group import NetworkSecurityGroup
from .network_security_group_vnic import NetworkSecurityGroupVnic
from .networking_topology import NetworkingTopology
from .no_route_routing_action import NoRouteRoutingAction
from .no_route_routing_action_details import NoRouteRoutingActionDetails
from .nsg_configuration import NsgConfiguration
from .path import Path
from .path_analysis_work_request_result import PathAnalysisWorkRequestResult
from .path_analyzer_test import PathAnalyzerTest
from .path_analyzer_test_collection import PathAnalyzerTestCollection
from .path_analyzer_test_summary import PathAnalyzerTestSummary
from .path_topology import PathTopology
from .persisted_get_path_analysis_details import PersistedGetPathAnalysisDetails
from .port_range import PortRange
from .private_ip import PrivateIp
from .protocol_parameters import ProtocolParameters
from .public_ip import PublicIp
from .query_options import QueryOptions
from .remote_peering_connection import RemotePeeringConnection
from .remote_peering_connection_drg_attachment_network_details import RemotePeeringConnectionDrgAttachmentNetworkDetails
from .remove_drg_route_distribution_statements_details import RemoveDrgRouteDistributionStatementsDetails
from .remove_drg_route_rules_details import RemoveDrgRouteRulesDetails
from .remove_network_security_group_security_rules_details import RemoveNetworkSecurityGroupSecurityRulesDetails
from .route_rule import RouteRule
from .route_table import RouteTable
from .routing_action import RoutingAction
from .security_action import SecurityAction
from .security_list import SecurityList
from .security_rule import SecurityRule
from .service import Service
from .service_gateway import ServiceGateway
from .service_id_request_details import ServiceIdRequestDetails
from .service_id_response_details import ServiceIdResponseDetails
from .stateful_egress_security_list_configuration import StatefulEgressSecurityListConfiguration
from .stateful_ingress_security_list_configuration import StatefulIngressSecurityListConfiguration
from .stateful_nsg_configuration import StatefulNsgConfiguration
from .subnet import Subnet
from .subnet_endpoint import SubnetEndpoint
from .subnet_topology import SubnetTopology
from .tcp_options import TcpOptions
from .tcp_protocol_parameters import TcpProtocolParameters
from .tcp_traffic_protocol_parameters import TcpTrafficProtocolParameters
from .topology import Topology
from .topology_associated_with_entity_relationship import TopologyAssociatedWithEntityRelationship
from .topology_associated_with_relationship_details import TopologyAssociatedWithRelationshipDetails
from .topology_contains_entity_relationship import TopologyContainsEntityRelationship
from .topology_entity_relationship import TopologyEntityRelationship
from .topology_routes_to_entity_relationship import TopologyRoutesToEntityRelationship
from .topology_routes_to_relationship_details import TopologyRoutesToRelationshipDetails
from .traffic_node import TrafficNode
from .traffic_protocol_parameters import TrafficProtocolParameters
from .traffic_route import TrafficRoute
from .tunnel_config import TunnelConfig
from .tunnel_status import TunnelStatus
from .udp_options import UdpOptions
from .udp_protocol_parameters import UdpProtocolParameters
from .udp_traffic_protocol_parameters import UdpTrafficProtocolParameters
from .update_cpe_details import UpdateCpeDetails
from .update_cross_connect_details import UpdateCrossConnectDetails
from .update_cross_connect_group_details import UpdateCrossConnectGroupDetails
from .update_dhcp_details import UpdateDhcpDetails
from .update_drg_attachment_details import UpdateDrgAttachmentDetails
from .update_drg_details import UpdateDrgDetails
from .update_drg_route_distribution_details import UpdateDrgRouteDistributionDetails
from .update_drg_route_distribution_statement_details import UpdateDrgRouteDistributionStatementDetails
from .update_drg_route_distribution_statements_details import UpdateDrgRouteDistributionStatementsDetails
from .update_drg_route_rule_details import UpdateDrgRouteRuleDetails
from .update_drg_route_rules_details import UpdateDrgRouteRulesDetails
from .update_drg_route_table_details import UpdateDrgRouteTableDetails
from .update_ip_sec_connection_details import UpdateIPSecConnectionDetails
from .update_internet_gateway_details import UpdateInternetGatewayDetails
from .update_ipv6_details import UpdateIpv6Details
from .update_local_peering_gateway_details import UpdateLocalPeeringGatewayDetails
from .update_network_security_group_details import UpdateNetworkSecurityGroupDetails
from .update_network_security_group_security_rules_details import UpdateNetworkSecurityGroupSecurityRulesDetails
from .update_path_analyzer_test_details import UpdatePathAnalyzerTestDetails
from .update_private_ip_details import UpdatePrivateIpDetails
from .update_public_ip_details import UpdatePublicIpDetails
from .update_remote_peering_connection_details import UpdateRemotePeeringConnectionDetails
from .update_route_table_details import UpdateRouteTableDetails
from .update_security_list_details import UpdateSecurityListDetails
from .update_security_rule_details import UpdateSecurityRuleDetails
from .update_service_gateway_details import UpdateServiceGatewayDetails
from .update_subnet_details import UpdateSubnetDetails
from .update_vcn_details import UpdateVcnDetails
from .update_virtual_circuit_details import UpdateVirtualCircuitDetails
from .update_vnic_details import UpdateVnicDetails
from .updated_network_security_group_security_rules import UpdatedNetworkSecurityGroupSecurityRules
from .upgrade_status import UpgradeStatus
from .vcn import Vcn
from .vcn_drg_attachment_network_create_details import VcnDrgAttachmentNetworkCreateDetails
from .vcn_drg_attachment_network_details import VcnDrgAttachmentNetworkDetails
from .vcn_drg_attachment_network_update_details import VcnDrgAttachmentNetworkUpdateDetails
from .vcn_routing_configuration import VcnRoutingConfiguration
from .vcn_topology import VcnTopology
from .virtual_circuit import VirtualCircuit
from .virtual_circuit_bandwidth_shape import VirtualCircuitBandwidthShape
from .virtual_circuit_drg_attachment_network_details import VirtualCircuitDrgAttachmentNetworkDetails
from .virtual_circuit_public_prefix import VirtualCircuitPublicPrefix
from .visible_traffic_node import VisibleTrafficNode
from .vlan_endpoint import VlanEndpoint
from .vnic import Vnic
from .vnic_endpoint import VnicEndpoint
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource
from .work_request_result import WorkRequestResult
from .work_request_result_collection import WorkRequestResultCollection
from .work_request_summary import WorkRequestSummary
from .work_request_summary_collection import WorkRequestSummaryCollection

# Maps type names to classes for vn_monitoring services.
vn_monitoring_type_mapping = {
    "AccessDeniedTrafficNode": AccessDeniedTrafficNode,
    "AddDrgRouteDistributionStatementDetails": AddDrgRouteDistributionStatementDetails,
    "AddDrgRouteDistributionStatementsDetails": AddDrgRouteDistributionStatementsDetails,
    "AddDrgRouteRuleDetails": AddDrgRouteRuleDetails,
    "AddDrgRouteRulesDetails": AddDrgRouteRulesDetails,
    "AddNetworkSecurityGroupSecurityRulesDetails": AddNetworkSecurityGroupSecurityRulesDetails,
    "AddSecurityRuleDetails": AddSecurityRuleDetails,
    "AddedNetworkSecurityGroupSecurityRules": AddedNetworkSecurityGroupSecurityRules,
    "AdhocGetPathAnalysisDetails": AdhocGetPathAnalysisDetails,
    "AllowedSecurityAction": AllowedSecurityAction,
    "AllowedSecurityActionDetails": AllowedSecurityActionDetails,
    "AllowedSecurityConfiguration": AllowedSecurityConfiguration,
    "BulkAddVirtualCircuitPublicPrefixesDetails": BulkAddVirtualCircuitPublicPrefixesDetails,
    "BulkDeleteVirtualCircuitPublicPrefixesDetails": BulkDeleteVirtualCircuitPublicPrefixesDetails,
    "ChangePathAnalyzerTestCompartmentDetails": ChangePathAnalyzerTestCompartmentDetails,
    "CompartmentInternal": CompartmentInternal,
    "ComputeInstanceEndpoint": ComputeInstanceEndpoint,
    "ConnectLocalPeeringGatewaysDetails": ConnectLocalPeeringGatewaysDetails,
    "ConnectRemotePeeringConnectionsDetails": ConnectRemotePeeringConnectionsDetails,
    "Cpe": Cpe,
    "CreateCpeDetails": CreateCpeDetails,
    "CreateCrossConnectDetails": CreateCrossConnectDetails,
    "CreateCrossConnectGroupDetails": CreateCrossConnectGroupDetails,
    "CreateDhcpDetails": CreateDhcpDetails,
    "CreateDrgAttachmentDetails": CreateDrgAttachmentDetails,
    "CreateDrgDetails": CreateDrgDetails,
    "CreateDrgRouteDistributionDetails": CreateDrgRouteDistributionDetails,
    "CreateDrgRouteTableDetails": CreateDrgRouteTableDetails,
    "CreateIPSecConnectionDetails": CreateIPSecConnectionDetails,
    "CreateInternetGatewayDetails": CreateInternetGatewayDetails,
    "CreateIpv6Details": CreateIpv6Details,
    "CreateLocalPeeringGatewayDetails": CreateLocalPeeringGatewayDetails,
    "CreateNetworkSecurityGroupDetails": CreateNetworkSecurityGroupDetails,
    "CreatePathAnalyzerTestDetails": CreatePathAnalyzerTestDetails,
    "CreatePrivateIpDetails": CreatePrivateIpDetails,
    "CreatePublicIpDetails": CreatePublicIpDetails,
    "CreateRemotePeeringConnectionDetails": CreateRemotePeeringConnectionDetails,
    "CreateRouteTableDetails": CreateRouteTableDetails,
    "CreateSecurityListDetails": CreateSecurityListDetails,
    "CreateServiceGatewayDetails": CreateServiceGatewayDetails,
    "CreateSubnetDetails": CreateSubnetDetails,
    "CreateVcnDetails": CreateVcnDetails,
    "CreateVirtualCircuitDetails": CreateVirtualCircuitDetails,
    "CreateVirtualCircuitPublicPrefixDetails": CreateVirtualCircuitPublicPrefixDetails,
    "CreateVnicDetails": CreateVnicDetails,
    "CrossConnect": CrossConnect,
    "CrossConnectGroup": CrossConnectGroup,
    "CrossConnectLocation": CrossConnectLocation,
    "CrossConnectMapping": CrossConnectMapping,
    "CrossConnectPortSpeedShape": CrossConnectPortSpeedShape,
    "CrossConnectStatus": CrossConnectStatus,
    "DefaultDrgRouteTables": DefaultDrgRouteTables,
    "DeleteVirtualCircuitPublicPrefixDetails": DeleteVirtualCircuitPublicPrefixDetails,
    "DeniedSecurityAction": DeniedSecurityAction,
    "DeniedSecurityActionDetails": DeniedSecurityActionDetails,
    "DhcpDnsOption": DhcpDnsOption,
    "DhcpOption": DhcpOption,
    "DhcpOptions": DhcpOptions,
    "DhcpSearchDomainOption": DhcpSearchDomainOption,
    "Drg": Drg,
    "DrgAttachment": DrgAttachment,
    "DrgAttachmentIdDrgRouteDistributionMatchCriteria": DrgAttachmentIdDrgRouteDistributionMatchCriteria,
    "DrgAttachmentInfo": DrgAttachmentInfo,
    "DrgAttachmentNetworkCreateDetails": DrgAttachmentNetworkCreateDetails,
    "DrgAttachmentNetworkDetails": DrgAttachmentNetworkDetails,
    "DrgAttachmentNetworkUpdateDetails": DrgAttachmentNetworkUpdateDetails,
    "DrgAttachmentTypeDrgRouteDistributionMatchCriteria": DrgAttachmentTypeDrgRouteDistributionMatchCriteria,
    "DrgRouteDistribution": DrgRouteDistribution,
    "DrgRouteDistributionMatchCriteria": DrgRouteDistributionMatchCriteria,
    "DrgRouteDistributionStatement": DrgRouteDistributionStatement,
    "DrgRouteRule": DrgRouteRule,
    "DrgRouteTable": DrgRouteTable,
    "DrgRoutingConfiguration": DrgRoutingConfiguration,
    "EgressSecurityListConfiguration": EgressSecurityListConfiguration,
    "EgressSecurityRule": EgressSecurityRule,
    "EgressTrafficSpec": EgressTrafficSpec,
    "Endpoint": Endpoint,
    "FastConnectProviderService": FastConnectProviderService,
    "ForwardedRoutingAction": ForwardedRoutingAction,
    "ForwardedRoutingActionDetails": ForwardedRoutingActionDetails,
    "ForwardedRoutingConfiguration": ForwardedRoutingConfiguration,
    "GetPathAnalysisDetails": GetPathAnalysisDetails,
    "GetPublicIpByIpAddressDetails": GetPublicIpByIpAddressDetails,
    "GetPublicIpByPrivateIpIdDetails": GetPublicIpByPrivateIpIdDetails,
    "IPSecConnection": IPSecConnection,
    "IPSecConnectionDeviceConfig": IPSecConnectionDeviceConfig,
    "IPSecConnectionDeviceStatus": IPSecConnectionDeviceStatus,
    "IcmpOptions": IcmpOptions,
    "IcmpProtocolParameters": IcmpProtocolParameters,
    "IcmpTrafficProtocolParameters": IcmpTrafficProtocolParameters,
    "IndeterminateRoutingAction": IndeterminateRoutingAction,
    "IngressSecurityListConfiguration": IngressSecurityListConfiguration,
    "IngressSecurityRule": IngressSecurityRule,
    "InternetGateway": InternetGateway,
    "IpAddressEndpoint": IpAddressEndpoint,
    "IpsecTunnelDrgAttachmentNetworkDetails": IpsecTunnelDrgAttachmentNetworkDetails,
    "Ipv6": Ipv6,
    "LetterOfAuthority": LetterOfAuthority,
    "LoadBalancerEndpoint": LoadBalancerEndpoint,
    "LoadBalancerListenerEndpoint": LoadBalancerListenerEndpoint,
    "LocalPeeringGateway": LocalPeeringGateway,
    "NetworkLoadBalancerEndpoint": NetworkLoadBalancerEndpoint,
    "NetworkLoadBalancerListenerEndpoint": NetworkLoadBalancerListenerEndpoint,
    "NetworkSecurityGroup": NetworkSecurityGroup,
    "NetworkSecurityGroupVnic": NetworkSecurityGroupVnic,
    "NetworkingTopology": NetworkingTopology,
    "NoRouteRoutingAction": NoRouteRoutingAction,
    "NoRouteRoutingActionDetails": NoRouteRoutingActionDetails,
    "NsgConfiguration": NsgConfiguration,
    "Path": Path,
    "PathAnalysisWorkRequestResult": PathAnalysisWorkRequestResult,
    "PathAnalyzerTest": PathAnalyzerTest,
    "PathAnalyzerTestCollection": PathAnalyzerTestCollection,
    "PathAnalyzerTestSummary": PathAnalyzerTestSummary,
    "PathTopology": PathTopology,
    "PersistedGetPathAnalysisDetails": PersistedGetPathAnalysisDetails,
    "PortRange": PortRange,
    "PrivateIp": PrivateIp,
    "ProtocolParameters": ProtocolParameters,
    "PublicIp": PublicIp,
    "QueryOptions": QueryOptions,
    "RemotePeeringConnection": RemotePeeringConnection,
    "RemotePeeringConnectionDrgAttachmentNetworkDetails": RemotePeeringConnectionDrgAttachmentNetworkDetails,
    "RemoveDrgRouteDistributionStatementsDetails": RemoveDrgRouteDistributionStatementsDetails,
    "RemoveDrgRouteRulesDetails": RemoveDrgRouteRulesDetails,
    "RemoveNetworkSecurityGroupSecurityRulesDetails": RemoveNetworkSecurityGroupSecurityRulesDetails,
    "RouteRule": RouteRule,
    "RouteTable": RouteTable,
    "RoutingAction": RoutingAction,
    "SecurityAction": SecurityAction,
    "SecurityList": SecurityList,
    "SecurityRule": SecurityRule,
    "Service": Service,
    "ServiceGateway": ServiceGateway,
    "ServiceIdRequestDetails": ServiceIdRequestDetails,
    "ServiceIdResponseDetails": ServiceIdResponseDetails,
    "StatefulEgressSecurityListConfiguration": StatefulEgressSecurityListConfiguration,
    "StatefulIngressSecurityListConfiguration": StatefulIngressSecurityListConfiguration,
    "StatefulNsgConfiguration": StatefulNsgConfiguration,
    "Subnet": Subnet,
    "SubnetEndpoint": SubnetEndpoint,
    "SubnetTopology": SubnetTopology,
    "TcpOptions": TcpOptions,
    "TcpProtocolParameters": TcpProtocolParameters,
    "TcpTrafficProtocolParameters": TcpTrafficProtocolParameters,
    "Topology": Topology,
    "TopologyAssociatedWithEntityRelationship": TopologyAssociatedWithEntityRelationship,
    "TopologyAssociatedWithRelationshipDetails": TopologyAssociatedWithRelationshipDetails,
    "TopologyContainsEntityRelationship": TopologyContainsEntityRelationship,
    "TopologyEntityRelationship": TopologyEntityRelationship,
    "TopologyRoutesToEntityRelationship": TopologyRoutesToEntityRelationship,
    "TopologyRoutesToRelationshipDetails": TopologyRoutesToRelationshipDetails,
    "TrafficNode": TrafficNode,
    "TrafficProtocolParameters": TrafficProtocolParameters,
    "TrafficRoute": TrafficRoute,
    "TunnelConfig": TunnelConfig,
    "TunnelStatus": TunnelStatus,
    "UdpOptions": UdpOptions,
    "UdpProtocolParameters": UdpProtocolParameters,
    "UdpTrafficProtocolParameters": UdpTrafficProtocolParameters,
    "UpdateCpeDetails": UpdateCpeDetails,
    "UpdateCrossConnectDetails": UpdateCrossConnectDetails,
    "UpdateCrossConnectGroupDetails": UpdateCrossConnectGroupDetails,
    "UpdateDhcpDetails": UpdateDhcpDetails,
    "UpdateDrgAttachmentDetails": UpdateDrgAttachmentDetails,
    "UpdateDrgDetails": UpdateDrgDetails,
    "UpdateDrgRouteDistributionDetails": UpdateDrgRouteDistributionDetails,
    "UpdateDrgRouteDistributionStatementDetails": UpdateDrgRouteDistributionStatementDetails,
    "UpdateDrgRouteDistributionStatementsDetails": UpdateDrgRouteDistributionStatementsDetails,
    "UpdateDrgRouteRuleDetails": UpdateDrgRouteRuleDetails,
    "UpdateDrgRouteRulesDetails": UpdateDrgRouteRulesDetails,
    "UpdateDrgRouteTableDetails": UpdateDrgRouteTableDetails,
    "UpdateIPSecConnectionDetails": UpdateIPSecConnectionDetails,
    "UpdateInternetGatewayDetails": UpdateInternetGatewayDetails,
    "UpdateIpv6Details": UpdateIpv6Details,
    "UpdateLocalPeeringGatewayDetails": UpdateLocalPeeringGatewayDetails,
    "UpdateNetworkSecurityGroupDetails": UpdateNetworkSecurityGroupDetails,
    "UpdateNetworkSecurityGroupSecurityRulesDetails": UpdateNetworkSecurityGroupSecurityRulesDetails,
    "UpdatePathAnalyzerTestDetails": UpdatePathAnalyzerTestDetails,
    "UpdatePrivateIpDetails": UpdatePrivateIpDetails,
    "UpdatePublicIpDetails": UpdatePublicIpDetails,
    "UpdateRemotePeeringConnectionDetails": UpdateRemotePeeringConnectionDetails,
    "UpdateRouteTableDetails": UpdateRouteTableDetails,
    "UpdateSecurityListDetails": UpdateSecurityListDetails,
    "UpdateSecurityRuleDetails": UpdateSecurityRuleDetails,
    "UpdateServiceGatewayDetails": UpdateServiceGatewayDetails,
    "UpdateSubnetDetails": UpdateSubnetDetails,
    "UpdateVcnDetails": UpdateVcnDetails,
    "UpdateVirtualCircuitDetails": UpdateVirtualCircuitDetails,
    "UpdateVnicDetails": UpdateVnicDetails,
    "UpdatedNetworkSecurityGroupSecurityRules": UpdatedNetworkSecurityGroupSecurityRules,
    "UpgradeStatus": UpgradeStatus,
    "Vcn": Vcn,
    "VcnDrgAttachmentNetworkCreateDetails": VcnDrgAttachmentNetworkCreateDetails,
    "VcnDrgAttachmentNetworkDetails": VcnDrgAttachmentNetworkDetails,
    "VcnDrgAttachmentNetworkUpdateDetails": VcnDrgAttachmentNetworkUpdateDetails,
    "VcnRoutingConfiguration": VcnRoutingConfiguration,
    "VcnTopology": VcnTopology,
    "VirtualCircuit": VirtualCircuit,
    "VirtualCircuitBandwidthShape": VirtualCircuitBandwidthShape,
    "VirtualCircuitDrgAttachmentNetworkDetails": VirtualCircuitDrgAttachmentNetworkDetails,
    "VirtualCircuitPublicPrefix": VirtualCircuitPublicPrefix,
    "VisibleTrafficNode": VisibleTrafficNode,
    "VlanEndpoint": VlanEndpoint,
    "Vnic": Vnic,
    "VnicEndpoint": VnicEndpoint,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestResult": WorkRequestResult,
    "WorkRequestResultCollection": WorkRequestResultCollection,
    "WorkRequestSummary": WorkRequestSummary,
    "WorkRequestSummaryCollection": WorkRequestSummaryCollection
}
